#!/usr/bin/env python
# -*- coding: utf-8 -*-

import uuid

from db_paribhasha.mongo import save_to_mongo
from db_paribhasha.mongo.dashboards.analysis_dashboards import AnalysisDashboards


def create_analysis_dashboard(workspace_id,
                              analysis_id,
                              sandboxed_dashboard_id,
                              status,
                              dashboard_name,
                              shared_dashboard_id=None,
                              document_id=None,
                              created_by=None,
                              modified_by=None,
                              dashboard_shared=False,
                              last_modified=None):
    """
    Creates an analysis dashboard document entry and saves it to mongo.

    Parameters
    ----------
    workspace_id : String
        Unqiue ID of the workspace
    analysis_id : String
        Unqiue ID of the analysis
    sandboxed_dashboard_id : String
        Unqiue ID of the dashboard in the sandbox
    shared_dashboard_id : String
        Unqiue ID of the dashboard shared
    """
    if document_id is None:
        document_id = str(uuid.uuid1())
    analysis_dashboard = AnalysisDashboards(
        document_id=document_id,
        workspace_id=str(workspace_id),
        analysis_id=str(analysis_id),
        sandboxed_dashboard_id=str(sandboxed_dashboard_id),
        shared_dashboard_id=str(shared_dashboard_id),
        status=status,
        dashboard_shared=dashboard_shared,
        last_modified=last_modified,
        created_by=created_by,
        modified_by=modified_by,
        dashboard_name=dashboard_name)
    save_to_mongo(analysis_dashboard)
    return document_id


def get_analysis_dashboards(workspace_id, analysis_id):
    """
    Returns a list of dashboards.

    Parameters
    ----------
    analysis_id : String
        Unique analysis ID

    Returns
    -------
    List
        List containing AnalysisPublicDashboards objects, if any.
    """
    collection = []
    dashboards = AnalysisDashboards.objects(analysis_id=str(analysis_id),
                                            workspace_id=str(workspace_id))
    for dashboard in dashboards:
        collection.append(to_dict(dashboard))
    return collection


def get_analysis_dashboard(workspace_id, analysis_id, sandboxed_dashboard_id):
    dashboards = AnalysisDashboards.objects(
                    analysis_id=str(analysis_id),
                    workspace_id=str(workspace_id),
                    sandboxed_dashboard_id=str(sandboxed_dashboard_id))
    
    if len(dashboards):
        return to_dict(dashboards[0])
    else:
        return to_dict(None)


def delete_analysis_dashboard(workspace_id, analysis_id, sandboxed_dashboard_id):
    AnalysisDashboards.objects(
        analysis_id=str(analysis_id),
        workspace_id=str(workspace_id),
        sandboxed_dashboard_id=str(sandboxed_dashboard_id)).delete()


def to_dict(obj):
    if obj is None:
        return {
            'document_id': None,
            'analysis_id': None,
            'workspace_id': None,
            'shared_dashboard_id': None,
            'sandboxed_dashboard_id': None,
            'status': None,
            'dashboard_shared': None,
            'dashboard_name': None,
            'created_by': None,
            'modified_by': None,
            'last_modified': None
        }
    return {
        'document_id': obj.document_id,
        'analysis_id': obj.analysis_id,
        'workspace_id': obj.workspace_id,
        'shared_dashboard_id': obj.shared_dashboard_id,
        'sandboxed_dashboard_id': obj.sandboxed_dashboard_id,
        'status': obj.status,
        'dashboard_shared': obj.dashboard_shared,
        'dashboard_name': obj.dashboard_name,
        'created_by': obj.created_by,
        'modified_by': obj.modified_by,
        'last_modified': str(obj.last_modified)
    }
