#!/usr/bin/env python
# -*- coding: utf-8 -*-


from db_paribhasha.mongo import save_to_mongo
from db_paribhasha.mongo.public_dashboards.analysis_public_dashboards import \
    AnalysisPublicDashboards
import datetime


def create_analysis_dashboard(analysis_id, dashboard_id, dashboard_url='',dataset_id='',dashboard_desc=''):
    """
    Creates an analysis dashboard document entry and saves it to mongo.

    Parameters
    ----------
    analysis_id : String
        Unqiue ID of the analysis
    dashboard_id : String
        Unique dashboard ID
    dashboard_url : str, optional
        URL of the generated dashboard, by default ''
    """
    analysis_dashboard = AnalysisPublicDashboards(analysis_id=str(analysis_id),
                                                  dashboard_id=str(dashboard_id),
                                                  dashboard_url=dashboard_url,
                                                  created_ts=datetime.datetime.utcnow(),
                                                  dataset_id=str(dataset_id),
                                                  dataset_desc=str(dashboard_desc))
    save_to_mongo(analysis_dashboard)


def get_dashboards(analysis_id):
    """
    Returns a list of dashboards.

    Parameters
    ----------
    analysis_id : String
        Unique analysis ID

    Returns
    -------
    List
        List containing AnalysisPublicDashboards objects, if any.
    """
    return AnalysisPublicDashboards.objects(analysis_id=str(analysis_id))


def get_analysis(dashboard_id):
    """
    Returns a list of matching analysis for the dashboard ID.

    Parameters
    ----------
    dashboard_id : String
        Unique Dashboard ID

    Returns
    -------
    List
        List containing AnalysisPublicDashboards objects, if any.
    """
    return AnalysisPublicDashboards.objects(dashboard_id=str(dashboard_id))


def get_collection():
    """
    Returns a list of collections in the mongodb.

    Returns
    -------
    List
        List containing collection objects, if any.
    """
    collections = AnalysisPublicDashboards.objects()
    all_collections = []
    for collection in collections:
        all_collections.append(to_dict(collection))
    return all_collections


def to_dict(obj):
    return {
            'created_ts': obj.created_ts,
            'analysis_id': obj.analysis_id,
            'dashboard_id': obj.dashboard_id,
            'dashboard_url': obj.dashboard_url,
            'dataset_id': obj.dataset_id,
            'dataset_desc': obj.dataset_desc
    }